@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2001-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2001-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL). If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -535,6 +535,8 @@ class Mnemo
     {
         $haveRemoved = false;
         $cs = unserialize($GLOBALS['prefs']->getValue('sync_notepads'));
+        // Ensure we have an actual non-empty value for any entry.
+        $cs = array_filter($cs);
         if (!empty($cs)) {
             if ($prune) {
                 $notepads =  self::listNotepads(true, Horde_Perms::DELETE);
